( cd usr/lib64 ; rm -rf libbz2.so )
( cd usr/lib64 ; ln -sf ../../lib64/libbz2.so.1 libbz2.so )
( cd usr/bin ; rm -rf bzip2 )
( cd usr/bin ; ln -sf ../../bin/bzip2 bzip2 )
( cd usr/bin ; rm -rf bunzip2 )
( cd usr/bin ; ln -sf ../../bin/bzip2 bunzip2 )
( cd usr/bin ; rm -rf bzcat )
( cd usr/bin ; ln -sf ../../bin/bzip2 bzcat )
( cd usr/bin ; rm -rf bzless )
( cd usr/bin ; ln -sf bzmore bzless )
( cd lib64 ; rm -rf libbz2.so.1.0 )
( cd lib64 ; ln -sf libbz2.so.1.0.3 libbz2.so.1.0 )
( cd lib64 ; rm -rf libbz2.so.1 )
( cd lib64 ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd bin ; rm -rf bunzip2 )
( cd bin ; ln -sf bzip2 bunzip2 )
( cd bin ; rm -rf bzcat )
( cd bin ; ln -sf bzip2 bzcat )
